
/* 
 * Copyright (c) 1993-2003,2012 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*------------------  Fichier gnr automatiquement ------------------*/
/*------------------  Ne pas diter manuellement !!! ------------------*/

#ifndef clone_MSG_LIB_H
#define clone_MSG_LIB_H

#include "portLib.h"
#include "csLib.h"
#include "posterLib.h"
 
#include "cloneType.h"

#define TIME_WAIT_REPLY           /*2000*/ 0
 



/*----------- Tailles des messages et boites aux lettres  ----------*/

/* Taille du buffer utilise dans la bal pour un mesage de taille size
 * (cf servMbox pour UNIX et h2rgnLib pour VXWORKS )
 */


#define BUF_SIZE(size) \
   (size + 4 - (size & 3) + sizeof(LETTER_HDR) + 8)

/**
 ** Boite aux lettres reception requetes 
 **/
#define  CLONE_MBOX_NAME                  genomInstanceName("clone")

#define  CLONE_MAX_RQST_SIZE              2048

#define  CLONE_MBOX_RQST_SIZE       \
 (BUF_SIZE(CLONE_MAX_RQST_SIZE) * SERV_NMAX_RQST_ID)

/** 
 ** Taille max repliques (serveur)
 **/
#define  CLONE_MAX_INTERMED_REPLY_SIZE   (sizeof(int))

#define  CLONE_MAX_REPLY_SIZE             512

/** 
 ** Taille bal clients pour reception repliques 
 **/
#define  CLONE_CLIENT_MBOX_REPLY_SIZE   \
((BUF_SIZE(CLONE_MAX_REPLY_SIZE) \
   + BUF_SIZE(CLONE_MAX_INTERMED_REPLY_SIZE)) \
 * CLIENT_NMAX_RQST_ID)

/*-------------------------- Liste des requetes  -------------------------*/

#define CLONE_INIT_RQST 0
#define CLONE_GETINITPARAMS_RQST 1
#define CLONE_POMPOSONOFF_RQST 2
#define CLONE_SETHIDEWINDOW_RQST 3
#define CLONE_GETHIDEWINDOW_RQST 4
#define CLONE_SETWINDOWGEOM_RQST 5
#define CLONE_GETWINDOWGEOM_RQST 6
#define CLONE_GETPLAYFILE_RQST 7
#define CLONE_PLAYFILE_RQST 8
#define CLONE_PLAYREF_RQST 9
#define CLONE_REPLAY_RQST 10
#define CLONE_CLEANFIFO_RQST 11
#define CLONE_STOPPLAY_RQST 12
#define CLONE_CLEANFILE_RQST 13
#define CLONE_EXPORTSENTENCE_RQST 14
#define CLONE_STOPLOOK_RQST 15
#define CLONE_LOOKAT_RQST 16
#define CLONE_HEADLOOKAT_RQST 17
#define CLONE_EYESLOOKAT_RQST 18
#define CLONE_HEADANDEYESLOOKAT_RQST 19
#define CLONE_STEREOTYPEMOTION_RQST 20
#define CLONE_LOOKATSPEECHOBJS_RQST 21
#define CLONE_ADDSPEECHOBJ_RQST 22
#define CLONE_REMOVESPEECHOBJ_RQST 23
#define CLONE_SETLOOKCORRECTION_RQST 24
#define CLONE_GETLOOKCORRECTION_RQST 25
#define CLONE_ABORT_RQST 26


/*---------------- PROTOTYPES DES FONCTIONS EXTERNES ------------------*/

#ifdef __cplusplus
extern "C" {
#endif

STATUS cloneClientInit (CLIENT_ID *pClientId);

STATUS cloneClientEnd (CLIENT_ID clientId);

int cloneAbortRqstSend (CLIENT_ID clientId, 
			   int *pRqstId,
			   int *activity,
			   int replyTimeOut);

int cloneAbortReplyRcv (CLIENT_ID clientId, 
			   int rqstId, 
			   int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			   int *bilan);

int cloneAbortRqstAndRcv (CLIENT_ID clientId, 
			     int *activity,
			     int *bilan);




extern STATUS cloneInitRqstSend (CLIENT_ID clientId, int *pRqstId,
					 CLONE_INIT *(in_initParams),
					 int replyTimeOut);

extern int cloneInitReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int cloneInitRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					CLONE_INIT *(in_initParams), 
					
					int *activity, int *bilan);

extern int cloneInitRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					CLONE_INIT *(in_initParams), 
					
					int *activity,
					int *bilan);




extern STATUS cloneGetInitParamsRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int cloneGetInitParamsReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       CLONE_INIT *(out_initParams),
			       int *bilan);

int cloneGetInitParamsRqstAndRcv (CLIENT_ID clientId, 
				  
				 CLONE_INIT *(out_initParams),
				 int *bilan);




extern STATUS clonePomPosOnOffRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 CLONE_BOOL *(in_pomOn),
					 int replyTimeOut);

int clonePomPosOnOffReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int clonePomPosOnOffRqstAndRcv (CLIENT_ID clientId, 
				 CLONE_BOOL *(in_pomOn), 
				 
				 int *bilan);




extern STATUS cloneSetHideWindowRqstSend (CLIENT_ID clientId, int *pRqstId,
					 CLONE_BOOL *(in_hideWindow),
					 int replyTimeOut);

extern int cloneSetHideWindowReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int cloneSetHideWindowRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					CLONE_BOOL *(in_hideWindow), 
					
					int *activity, int *bilan);

extern int cloneSetHideWindowRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					CLONE_BOOL *(in_hideWindow), 
					
					int *activity,
					int *bilan);




extern STATUS cloneGetHideWindowRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int cloneGetHideWindowReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       CLONE_BOOL *(out_hideWindow),
			       int *bilan);

int cloneGetHideWindowRqstAndRcv (CLIENT_ID clientId, 
				  
				 CLONE_BOOL *(out_hideWindow),
				 int *bilan);




extern STATUS cloneSetWindowGeomRqstSend (CLIENT_ID clientId, int *pRqstId,
					 CLONE_WINDOW_PARAMS *(in_windowParams),
					 int replyTimeOut);

extern int cloneSetWindowGeomReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int cloneSetWindowGeomRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					CLONE_WINDOW_PARAMS *(in_windowParams), 
					
					int *activity, int *bilan);

extern int cloneSetWindowGeomRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					CLONE_WINDOW_PARAMS *(in_windowParams), 
					
					int *activity,
					int *bilan);




extern STATUS cloneGetWindowGeomRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int cloneGetWindowGeomReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       CLONE_WINDOW_PARAMS *(out_windowParams),
			       int *bilan);

int cloneGetWindowGeomRqstAndRcv (CLIENT_ID clientId, 
				  
				 CLONE_WINDOW_PARAMS *(out_windowParams),
				 int *bilan);




extern STATUS cloneGetPlayFileRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int cloneGetPlayFileReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       CLONE_PLAY_FILE_PARAMS *(out_playFileParams),
			       int *bilan);

int cloneGetPlayFileRqstAndRcv (CLIENT_ID clientId, 
				  
				 CLONE_PLAY_FILE_PARAMS *(out_playFileParams),
				 int *bilan);




extern STATUS clonePlayFileRqstSend (CLIENT_ID clientId, int *pRqstId,
					 CLONE_PLAY_FILE_PARAMS *(in_playFileParams),
					 int replyTimeOut);

extern int clonePlayFileReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int clonePlayFileRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					CLONE_PLAY_FILE_PARAMS *(in_playFileParams), 
					
					int *activity, int *bilan);

extern int clonePlayFileRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					CLONE_PLAY_FILE_PARAMS *(in_playFileParams), 
					
					int *activity,
					int *bilan);




extern STATUS clonePlayRefRqstSend (CLIENT_ID clientId, int *pRqstId,
					 int *(in_playRefParams),
					 int replyTimeOut);

extern int clonePlayRefReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int clonePlayRefRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					int *(in_playRefParams), 
					
					int *activity, int *bilan);

extern int clonePlayRefRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					int *(in_playRefParams), 
					
					int *activity,
					int *bilan);




extern STATUS cloneRePlayRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int cloneRePlayReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int cloneRePlayRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int cloneRePlayRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS cloneCleanFifoRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int cloneCleanFifoReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int cloneCleanFifoRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int cloneCleanFifoRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS cloneStopPlayRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int cloneStopPlayReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int cloneStopPlayRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int cloneStopPlayRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS cloneCleanFileRqstSend (CLIENT_ID clientId, int *pRqstId,
					 CLONE_PLAY_FILE_PARAMS *(in_playFileParams),
					 int replyTimeOut);

extern int cloneCleanFileReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int cloneCleanFileRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					CLONE_PLAY_FILE_PARAMS *(in_playFileParams), 
					
					int *activity, int *bilan);

extern int cloneCleanFileRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					CLONE_PLAY_FILE_PARAMS *(in_playFileParams), 
					
					int *activity,
					int *bilan);




extern STATUS cloneExportSentenceRqstSend (CLIENT_ID clientId, int *pRqstId,
					 CLONE_SENTENCE *(in_sentence),
					 int replyTimeOut);

extern int cloneExportSentenceReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int cloneExportSentenceRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					CLONE_SENTENCE *(in_sentence), 
					
					int *activity, int *bilan);

extern int cloneExportSentenceRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					CLONE_SENTENCE *(in_sentence), 
					
					int *activity,
					int *bilan);




extern STATUS cloneStopLookRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int cloneStopLookReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int cloneStopLookRqstAndRcv (CLIENT_ID clientId, 
				  
				 
				 int *bilan);




extern STATUS cloneLookAtRqstSend (CLIENT_ID clientId, int *pRqstId,
					 CLONE_LOOK_AT *(in_lookAt),
					 int replyTimeOut);

extern int cloneLookAtReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int cloneLookAtRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					CLONE_LOOK_AT *(in_lookAt), 
					
					int *activity, int *bilan);

extern int cloneLookAtRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					CLONE_LOOK_AT *(in_lookAt), 
					
					int *activity,
					int *bilan);




extern STATUS cloneHeadLookAtRqstSend (CLIENT_ID clientId, int *pRqstId,
					 CLONE_LOOK_AT_POINT *(in_headLookAt),
					 int replyTimeOut);

extern int cloneHeadLookAtReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int cloneHeadLookAtRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					CLONE_LOOK_AT_POINT *(in_headLookAt), 
					
					int *activity, int *bilan);

extern int cloneHeadLookAtRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					CLONE_LOOK_AT_POINT *(in_headLookAt), 
					
					int *activity,
					int *bilan);




extern STATUS cloneEyesLookAtRqstSend (CLIENT_ID clientId, int *pRqstId,
					 CLONE_LOOK_AT_POINT *(in_eyesLookAt),
					 int replyTimeOut);

extern int cloneEyesLookAtReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int cloneEyesLookAtRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					CLONE_LOOK_AT_POINT *(in_eyesLookAt), 
					
					int *activity, int *bilan);

extern int cloneEyesLookAtRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					CLONE_LOOK_AT_POINT *(in_eyesLookAt), 
					
					int *activity,
					int *bilan);




extern STATUS cloneHeadAndEyesLookAtRqstSend (CLIENT_ID clientId, int *pRqstId,
					 CLONE_LOOK_AT_POINT *(in_headAndEyesLookAt),
					 int replyTimeOut);

extern int cloneHeadAndEyesLookAtReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int cloneHeadAndEyesLookAtRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					CLONE_LOOK_AT_POINT *(in_headAndEyesLookAt), 
					
					int *activity, int *bilan);

extern int cloneHeadAndEyesLookAtRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					CLONE_LOOK_AT_POINT *(in_headAndEyesLookAt), 
					
					int *activity,
					int *bilan);




extern STATUS cloneStereotypeMotionRqstSend (CLIENT_ID clientId, int *pRqstId,
					 CLONE_STEREOTYPE *(in_stereotype),
					 int replyTimeOut);

extern int cloneStereotypeMotionReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int cloneStereotypeMotionRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					CLONE_STEREOTYPE *(in_stereotype), 
					
					int *activity, int *bilan);

extern int cloneStereotypeMotionRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					CLONE_STEREOTYPE *(in_stereotype), 
					
					int *activity,
					int *bilan);




extern STATUS cloneLookAtSpeechObjsRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int cloneLookAtSpeechObjsReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int cloneLookAtSpeechObjsRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int cloneLookAtSpeechObjsRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS cloneAddSpeechObjRqstSend (CLIENT_ID clientId, int *pRqstId,
					 CLONE_SPEECH_OBJ *(in_speechObj),
					 int replyTimeOut);

extern int cloneAddSpeechObjReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int cloneAddSpeechObjRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					CLONE_SPEECH_OBJ *(in_speechObj), 
					
					int *activity, int *bilan);

extern int cloneAddSpeechObjRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					CLONE_SPEECH_OBJ *(in_speechObj), 
					
					int *activity,
					int *bilan);




extern STATUS cloneRemoveSpeechObjRqstSend (CLIENT_ID clientId, int *pRqstId,
					 GEN_STRING256 *(in_speechObjName),
					 int replyTimeOut);

extern int cloneRemoveSpeechObjReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int cloneRemoveSpeechObjRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					GEN_STRING256 *(in_speechObjName), 
					
					int *activity, int *bilan);

extern int cloneRemoveSpeechObjRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					GEN_STRING256 *(in_speechObjName), 
					
					int *activity,
					int *bilan);




extern STATUS cloneSetLookCorrectionRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 CLONE_POS_CORR *(in_lookCorrection),
					 int replyTimeOut);

int cloneSetLookCorrectionReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int cloneSetLookCorrectionRqstAndRcv (CLIENT_ID clientId, 
				 CLONE_POS_CORR *(in_lookCorrection), 
				 
				 int *bilan);




extern STATUS cloneGetLookCorrectionRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int cloneGetLookCorrectionReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       CLONE_POS_CORR *(out_lookCorrection),
			       int *bilan);

int cloneGetLookCorrectionRqstAndRcv (CLIENT_ID clientId, 
				  
				 CLONE_POS_CORR *(out_lookCorrection),
				 int *bilan);


#ifdef __cplusplus
}
#endif
#endif /* clone_MSG_LIB_H */

